==> douluo-ui-1.0.2.tgz: package/lib/button.common.js <==
/*
* douluo-ui v1.0.2
* Copyright ©2022-2022 
* Released under the MIT License.
*/
'use strict';

let componentNamespace = 'dl'; // 组件前缀命名只能更新一次，防止重复执行修改组件注册出错

let isUpdated = false; // scss 命名不能通过 js 更改，在 SCSS 编译已经打包好了

const cssNamespace = 'dl';
const statePrefix = 'is-';
function createNamespace(name, {
  prefix
}) {
  if (!isUpdated) {
    isUpdated = true;
    componentNamespace = prefix || componentNamespace; // 更改前缀
  }

  return componentNamespace + name.charAt(0).toUpperCase() + name.substr(1);
}
/**
 * 生成 bem
 * @param {} namespace 命名空间
 * @param {*} block 块
 * @param {*} blockSuffix 块多个单词
 * @param {*} element 元素
 * @param {*} modifier 修饰符
 * @returns
 */

const _bem = (namespace, block, blockSuffix, element, modifier) => {
  let cls = `${namespace}-${block}`;

  if (blockSuffix) {
    cls += `-${blockSuffix}`;
  }

  if (element) {
    cls += `__${element}`;
  }

  if (modifier) {
    cls += `--${modifier}`;
  }

  return cls;
};

const useNamespace = block => {
  const namespace = cssNamespace;

  const b = (blockSuffix = '') => _bem(namespace, block, blockSuffix, '', '');

  const e = element => element ? _bem(namespace, block, '', element, '') : '';

  const m = modifier => modifier ? _bem(namespace, block, '', '', modifier) : '';

  const be = (blockSuffix, element) => blockSuffix && element ? _bem(namespace, block, blockSuffix, element, '') : '';

  const em = (element, modifier) => element && modifier ? _bem(namespace, block, '', element, modifier) : '';

  const bm = (blockSuffix, modifier) => blockSuffix && modifier ? _bem(namespace, block, blockSuffix, '', modifier) : '';

  const bem = (blockSuffix, element, modifier) => blockSuffix && element && modifier ? _bem(namespace, block, blockSuffix, element, modifier) : '';

  const is = (name, ...args) => {
    const state = args.length >= 1 ? args[0] : true;
    return name && state ? `${statePrefix}${name}` : '';
  }; // for css var
  // --el-xxx: value;


  const cssVar = object => {
    const styles = {};

    for (const key in object) {
      styles[`--${namespace}-${key}`] = object[key];
    }

    return styles;
  }; // with block


  const cssVarBlock = object => {
    const styles = {};

    for (const key in object) {
      styles[`--${namespace}-${block}-${key}`] = object[key];
    }

    return styles;
  };

  const cssVarName = name => `--${namespace}-${name}`;

  const cssVarBlockName = name => `--${namespace}-${block}-${name}`;

  return {
    cssNamespace,
    componentNamespace,
    b,
    e,
    m,
    be,
    em,
    bm,
    bem,
    is,
    // css
    cssVar,
    cssVarName,
    cssVarBlock,
    cssVarBlockName
  };
};

//
var script = {
  name: 'Button',

  data() {
    this.ns = useNamespace('button');
    return {};
  }

};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "el-button",
    _vm._g(
      _vm._b({ class: [_vm.ns.b()] }, "el-button", _vm.$attrs, false),
      _vm.$listeners
    ),
    [_vm._t("default")],
    2
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

__vue_component__.install = (Vue, options = {}) => {
  Vue.component(createNamespace("button", {
    prefix: options.prefix
  }), __vue_component__);
};

module.exports = __vue_component__;

==> douluo-ui-1.0.3.tgz: package/lib/button.common.js <==
/*
* douluo-ui v1.0.3
* Copyright ©2022-2022 
* Released under the MIT License.
*/
'use strict';

let componentNamespace = 'dl'; // 组件前缀命名只能更新一次，防止重复执行修改组件注册出错

let isUpdated = false; // scss 命名不能通过 js 更改，在 SCSS 编译已经打包好了

const cssNamespace = 'dl';
const statePrefix = 'is-';
function createNamespace(name, {
  prefix
}) {
  if (!isUpdated) {
    isUpdated = true;
    componentNamespace = prefix || componentNamespace; // 更改前缀
  }

  return componentNamespace + name.charAt(0).toUpperCase() + name.substr(1);
}
/**
 * 生成 bem
 * @param {} namespace 命名空间
 * @param {*} block 块
 * @param {*} blockSuffix 块多个单词
 * @param {*} element 元素
 * @param {*} modifier 修饰符
 * @returns
 */

const _bem = (namespace, block, blockSuffix, element, modifier) => {
  let cls = `${namespace}-${block}`;

  if (blockSuffix) {
    cls += `-${blockSuffix}`;
  }

  if (element) {
    cls += `__${element}`;
  }

  if (modifier) {
    cls += `--${modifier}`;
  }

  return cls;
};

const useNamespace = block => {
  const namespace = cssNamespace;

  const b = (blockSuffix = '') => _bem(namespace, block, blockSuffix, '', '');

  const e = element => element ? _bem(namespace, block, '', element, '') : '';

  const m = modifier => modifier ? _bem(namespace, block, '', '', modifier) : '';

  const be = (blockSuffix, element) => blockSuffix && element ? _bem(namespace, block, blockSuffix, element, '') : '';

  const em = (element, modifier) => element && modifier ? _bem(namespace, block, '', element, modifier) : '';

  const bm = (blockSuffix, modifier) => blockSuffix && modifier ? _bem(namespace, block, blockSuffix, '', modifier) : '';

  const bem = (blockSuffix, element, modifier) => blockSuffix && element && modifier ? _bem(namespace, block, blockSuffix, element, modifier) : '';

  const is = (name, ...args) => {
    const state = args.length >= 1 ? args[0] : true;
    return name && state ? `${statePrefix}${name}` : '';
  }; // for css var
  // --el-xxx: value;


  const cssVar = object => {
    const styles = {};

    for (const key in object) {
      styles[`--${namespace}-${key}`] = object[key];
    }

    return styles;
  }; // with block


  const cssVarBlock = object => {
    const styles = {};

    for (const key in object) {
      styles[`--${namespace}-${block}-${key}`] = object[key];
    }

    return styles;
  };

  const cssVarName = name => `--${namespace}-${name}`;

  const cssVarBlockName = name => `--${namespace}-${block}-${name}`;

  return {
    cssNamespace,
    componentNamespace,
    b,
    e,
    m,
    be,
    em,
    bm,
    bem,
    is,
    // css
    cssVar,
    cssVarName,
    cssVarBlock,
    cssVarBlockName
  };
};

//
var script = {
  name: 'Button',
  props: {
    type: {
      type: String,
      default: 'default'
    },
    size: {
      type: String,
      default: ''
    },
    icon: {
      type: String,
      default: ''
    },
    nativeType: {
      type: String,
      default: 'button'
    },
    loading: Boolean,
    disabled: Boolean,
    plain: Boolean,
    ghost: Boolean,
    autofocus: Boolean,
    round: Boolean,
    circle: Boolean,
    link: Boolean,
    text: Boolean
  },

  data() {
    this.ns = useNamespace('button');
    return {};
  },

  computed: {
    _dlFormItemSize() {
      return (this.dlFormItem || {}).dlFormItemSize;
    },

    buttonSize() {
      return this.size || this._dlFormItemSize || (this.$ELEMENT || {}).size;
    },

    buttonDisabled() {
      return this.disabled || (this.dlForm || {}).disabled;
    }

  },
  methods: {
    handleClick(evt) {
      this.$emit('click', evt);
    }

  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "button",
    {
      class: [
        _vm.ns.b(),
        _vm.ns.m(_vm.type),
        _vm.ns.m(_vm.buttonSize),
        _vm.ns.is("disabled", _vm.buttonDisabled),
        _vm.ns.is("loading", _vm.loading),
        _vm.ns.is("plain", _vm.plain),
        _vm.ns.is("ghost", _vm.ghost),
        _vm.ns.is("round", _vm.round),
        _vm.ns.is("circle", _vm.circle),
        _vm.ns.is("text", _vm.text),
        _vm.ns.is("link", _vm.link),
      ],
      attrs: {
        disabled: _vm.buttonDisabled || _vm.loading,
        autofocus: _vm.autofocus,
        type: _vm.nativeType,
      },
      on: { click: _vm.handleClick },
    },
    [
      _vm.loading
        ? [
            _vm.$slots.loading
              ? _vm._t("loading")
              : _c("i", { staticClass: "el-icon-loading" }),
          ]
        : _vm.icon || _vm.$slots.icon
        ? [
            _vm.$slots.icon
              ? _c("span", [_vm._t("icon")], 2)
              : _c("i", { class: _vm.icon }),
          ]
        : _vm._e(),
      _vm._v(" "),
      _vm.$slots.default ? _c("span", [_vm._t("default")], 2) : _vm._e(),
    ],
    2
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

__vue_component__.install = (Vue, options = {}) => {
  Vue.component(createNamespace('button', {
    prefix: options.prefix
  }), __vue_component__);
};

module.exports = __vue_component__;
